@@ -27,6 +27,13 @@
 
 #include <string.h>
 
+/**
+ * SECTION: gog-series
+ * @short_description: A single data series.
+ *
+ * A #GogSeries represents a data series that can be added to a #GogPlot.
+ */
+
 /* Keep in sync with GogSeriesFillType enum */
 static struct {
 	GogSeriesFillType  type;
@@ -502,7 +509,7 @@ gog_series_populate_editor (GogObject *gobj,
 	gtk_table_attach (table, gtk_hseparator_new (),
 		0, 2, row, row+1, GTK_FILL, 0, 0, 0);
 	row++;
-	w = gtk_check_button_new_with_mnemonic ("_Show in Legend");
+	w = gtk_check_button_new_with_mnemonic (_("_Show in Legend"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
 		gog_series_has_legend (series));
 	g_signal_connect (G_OBJECT (w),
@@ -946,7 +953,7 @@ gog_series_get_name (GogSeries const *series)
  * gog_series_set_name :
  * @series : a #GogSeries
  * @name_src : a #GODataScalar
- * @err : a #Gerror
+ * @err : a #GError
  *
  * Absorbs a ref to @name_src.
  *
@@ -962,7 +969,7 @@ gog_series_set_name (GogSeries *series, GODataScalar *name_src, GError **err)
  * @series : #GogSeries
  * @dim_i : Which dimension
  * @val   : #GOData
- * @err : optional #Gerror pointer
+ * @err : optional #GError pointer
  *
  * Absorbs a ref to @val
  **/
