@@ -831,16 +831,14 @@ set_format_category (GOFormatSel *gfs, int row)
 }
 
 static GOFormatFamily
-study_format (GOFormatSel *gfs)
+study_format (GOFormat const *fmt, GOFormatDetails *details)
 {
-	const GOFormat *fmt = gfs->format.spec;
 	gboolean exact;
-	GOFormatDetails *details = &gfs->format.details;
 
 	go_format_get_details (fmt, details, &exact);
 
 	if (exact) {
-		/* Thing we do not have GUI for: */
+		/* Things we do not have GUI for: */
 		if (details->family == GO_FORMAT_ACCOUNTING &&
 		    !details->thousands_sep)
 			exact = FALSE;
@@ -853,12 +851,11 @@ study_format (GOFormatSel *gfs)
 		const char *str = go_format_as_XL (fmt);
 		if (!find_builtin (str, details->family, FALSE))
 			details->family = FMT_CUSTOM;
-	}
-
+	}	
+	
 	return details->family;
 }
 
-
 static void
 set_format_category_menu_from_style (GOFormatSel *gfs)
 {
@@ -867,7 +864,7 @@ set_format_category_menu_from_style (GOFormatSel *gfs)
 	g_return_if_fail (GO_IS_FORMAT_SEL (gfs));
 
 	/* Attempt to extract general parameters from the current format */
-	page = study_format (gfs);
+	page = study_format (gfs->format.spec, &gfs->format.details);
 	if (page < 0)
 		page = FMT_CUSTOM; /* Default to custom */
 
@@ -888,6 +885,7 @@ populate_menu (GOFormatSel *gfs)
 						 (1, G_TYPE_STRING));
 	gtk_tree_view_set_model (GTK_TREE_VIEW (gfs->format.menu),
 				 gfs->format.menu_model);
+	g_object_unref (gfs->format.menu_model);
 	selection = gtk_tree_view_get_selection
 		(GTK_TREE_VIEW(gfs->format.menu));
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
@@ -981,7 +979,7 @@ nfs_init (GOFormatSel *gfs)
 	 * all widgets are already hidden. */
 	gfs->format.current_type = -1;
 
-	study_format (gfs);
+	study_format (gfs->format.spec, &gfs->format.details);
 
 	gfs->format.preview_box = go_gtk_builder_get_widget (gfs->gui, "preview_box");
 	gfs->format.preview = GTK_TEXT_VIEW (gtk_builder_get_object (gfs->gui, "preview"));
@@ -1048,6 +1046,8 @@ nfs_init (GOFormatSel *gfs)
 	gfs->format.negative_types.view = GTK_TREE_VIEW (gfs->format.widget[F_NEGATIVE]);
 	gtk_tree_view_set_model (gfs->format.negative_types.view,
 				 GTK_TREE_MODEL (gfs->format.negative_types.model));
+	g_object_unref (gfs->format.negative_types.model);
+
 	column = gtk_tree_view_column_new_with_attributes
 		(_("Negative Number Format"),
 		 gtk_cell_renderer_text_new (),
@@ -1076,7 +1076,8 @@ nfs_init (GOFormatSel *gfs)
 	gfs->format.formats.model = gtk_list_store_new (1, G_TYPE_STRING);
 	gfs->format.formats.view = GTK_TREE_VIEW (gfs->format.widget[F_LIST]);
 	gtk_tree_view_set_model (gfs->format.formats.view,
-		GTK_TREE_MODEL (gfs->format.formats.model));
+				 GTK_TREE_MODEL (gfs->format.formats.model));
+	g_object_unref (gfs->format.formats.model);
 	column = gtk_tree_view_column_new_with_attributes (_("Number Formats"),
 		gtk_cell_renderer_text_new (),
 		"text",		0,
@@ -1264,7 +1265,7 @@ go_format_sel_set_style_format (GOFormatSel *gfs,
 	go_format_unref (gfs->format.spec);
 	gfs->format.spec = style_format;
 
-	study_format (gfs);
+	study_format (gfs->format.spec, &gfs->format.details);
 
 	combo = GO_COMBO_TEXT (gfs->format.widget[F_SYMBOL]);
 	if (gfs->format.details.currency) {
@@ -1348,7 +1349,10 @@ go_format_sel_set_locale (GOFormatSel *gfs,
 char const *
 go_format_sel_format_classification (GOFormat const *style_format)
 {
-	GOFormatFamily page = go_format_get_family (style_format);
+	GOFormatFamily page;
+	GOFormatDetails details;
+
+	page = study_format (style_format, &details);
 
 	if (page < 0 || page > FMT_CUSTOM)
 		page = FMT_CUSTOM; /* Default to custom */
